@@ -21,16 +21,10 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.hint import CautiousDefaultHint
-
-# from pysollib.util import ANY_SUIT, KING
-
+from pysollib.layout import Layout
 from pysollib.stack import \
         AC_RowStack, \
         InitialDealTalonStack, \
