@@ -54,6 +54,9 @@ class PokerSquare(Game):
     Hint_Class = None
 
     WIN_SCORE = 100
+    NUM_RESERVE = 0
+    RESERVE_STACK = StackWrapper(ReserveStack, max_cards=5)
+    UNSCORED = False
 
     #
     # game layout
@@ -66,22 +69,22 @@ class PokerSquare(Game):
         # create texts 1)
         ta = "ss"
         x, y = l.XM, l.YM + 2*l.YS
-        if self.preview <= 1:
+        if self.preview <= 1 and not self.UNSCORED:
             t = MfxCanvasText(self.canvas, x, y, anchor="nw",
                               font=self.app.getFont("canvas_default"),
                               text=_('''\
 Royal Flush
 Straight Flush
-Four of a Kind
+4 of a Kind
 Full House
 Flush
 Straight
-Three of a Kind
+3 of a Kind
 Two Pair
 One Pair'''))
             self.texts.list.append(t)
             bb = t.bbox()
-            x = bb[1][0] + 16
+            x = bb[1][0] + l.CW * 1.3
             h = bb[1][1] - bb[0][1]
             if h >= 2*l.YS:
                 ta = "e"
@@ -91,7 +94,7 @@ One Pair'''))
                               font=self.app.getFont("canvas_default"),
                               text="100\n75\n50\n25\n20\n15\n10\n5\n2")
             self.texts.list.append(t)
-            x = t.bbox()[1][0] + 16
+            x = t.bbox()[1][0] + l.CW * .6
             self.texts.misc = MfxCanvasText(
                 self.canvas, x, y, anchor="nw",
                 font=self.app.getFont("canvas_default"),
@@ -99,8 +102,12 @@ One Pair'''))
             x = self.texts.misc.bbox()[1][0] + 32
 
         # set window
-        w = max(2*l.XS, x)
-        self.setSize(l.XM + w + 5*l.XS + 50, l.YM + 5*l.YS + 30)
+        if not self.UNSCORED:
+            w = max(2 * l.XS, x, ((self.NUM_RESERVE + 1) * l.XS) + (4 * l.XM))
+            self.setSize(l.XM + w + 5 * l.XS + 50, l.YM + 5 * l.YS + 30)
+        else:
+            w = l.XM
+            self.setSize(l.XM + w + 5 * l.XS + 100, l.YM + 5 * l.YS)
 
         # create stacks
         for i in range(5):
@@ -108,10 +115,16 @@ One Pair'''))
                 x, y = l.XM + w + j*l.XS, l.YM + i*l.YS
                 s.rows.append(self.RowStack_Class(x, y, self))
         x, y = l.XM, l.YM
+        if self.UNSCORED:
+            x += (4 * l.YS)
         s.talon = self.Talon_Class(x, y, self)
         l.createText(s.talon, anchor=ta)
         s.internals.append(InvisibleStack(self))    # for _swapPairMove()
 
+        for i in range(self.NUM_RESERVE):
+            x, y = ((i + 1) * l.XS) + (2 * l.XM), l.YM
+            s.reserves.append(self.RESERVE_STACK(x, y, self))
+
         # create texts 2)
         if self.preview <= 1:
             for i in (4, 9, 14, 19, 24):
@@ -150,12 +163,21 @@ One Pair'''))
     #
 
     def startGame(self):
-        self.moveMove(27, self.s.talon, self.s.internals[0], frames=0)
+        self.moveMove(27 - (5 * self.NUM_RESERVE), self.s.talon,
+                      self.s.internals[0], frames=0)
         self.s.talon.fillStack()
 
+    def isBoardFull(self):
+        for i in range(25):
+            if len(self.s.rows[i].cards) == 0:
+                return False
+        return True
+
     def isGameWon(self):
-        return len(self.s.talon.cards) == 0 and \
-            self.getGameScore() >= self.WIN_SCORE
+        if self.isBoardFull():
+            return self.getGameScore() >= self.WIN_SCORE
+
+        return False
 
     def getAutoStacks(self, event=None):
         return ((), (), ())
@@ -172,21 +194,37 @@ One Pair'''))
         for i in range(10):
             type, value = self.getHandScore(self.poker_hands[i])
             if 0 <= type <= 8:
-                count[type] = count[type] + 1
+                count[type] += 1
             self.texts.list[i+2].config(text=str(value))
-            score = score + value
+            score += value
         t = '\n'.join(map(str, count))
         self.texts.misc.config(text=t)
         #
         t = ""
         if score >= self.WIN_SCORE:
             t = _("WON\n\n")
-        if self.s.talon.cards:
-            t = t + _("Points: %d") % score
+        if not self.isBoardFull():
+            t += _("Points: %d") % score
         else:
-            t = t + _("Total: %d") % score
+            t += _("Total: %d") % score
         self.texts.score.config(text=t)
 
+    def parseGameInfo(self):
+        return _("Points: %d") % self.getGameScore()
+
+    def parseStackInfo(self, stack):
+        if stack not in self.s.rows:
+            return ""
+        stackhands = []
+        for hand in self.poker_hands:
+            if stack in hand:
+                stackhands.append(hand)
+        row = (stack.id % 5) + 1
+        column = (stack.id // 5) + 1
+        return (_("Row: %d, Score %d, Column: %d, Score %d") %
+                (row, self.getHandScore(stackhands[0])[1], column,
+                 self.getHandScore(stackhands[1])[1]))
+
     def getGameScore(self):
         score = 0
         for hand in self.poker_hands:
@@ -274,8 +312,81 @@ class PokerShuffle(PokerSquare):
         self.moveMove(27, self.s.talon, self.s.internals[0], frames=0)
         self._startAndDealRow()
 
-    def checkForWin(self):
-        return 0
+
+# ************************************************************************
+# * Poker Square (Waste)
+# * Poker Square (1 Reserve)
+# * Poker Square (2 Reserves)
+# ************************************************************************
+
+class PokerSquareWaste(PokerSquare):
+    NUM_RESERVE = 1
+    RESERVE_STACK = StackWrapper(ReserveStack, max_cards=5, max_move=0)
+
+
+class PokerSquare1Reserve(PokerSquare):
+    NUM_RESERVE = 1
+
+
+class PokerSquare2Reserves(PokerSquare):
+    NUM_RESERVE = 2
+
+
+# ************************************************************************
+# * Maverick
+# ************************************************************************
+
+class Maverick(PokerShuffle):
+    UNSCORED = True
+
+    def createGame(self):
+        PokerShuffle.createGame(self)
+        r = self.s.rows
+        self.poker_hands = [r[0:5], r[5:10], r[10:15], r[15:20], r[20:25]]
+
+    def updateText(self):
+        if self.preview > 1:
+            return
+
+        for i in range(5):
+            type, value = self.getHandScore(self.poker_hands[i])
+            self.texts.list[i].config(text=self.getNameByScore(value))
+
+    def getNameByScore(self, score):
+        scores = {0: "Nothing",
+                  2: "One Pair",
+                  5: "Two Pair",
+                  10: "3 of a Kind",
+                  15: "Straight",
+                  20: "Flush",
+                  25: "Full House",
+                  50: "4 of a Kind",
+                  75: "Straight Flush",
+                  100: "Royal Flush"}
+        return scores[score]
+
+    def parseGameInfo(self):
+        return ''
+
+    def parseStackInfo(self, stack):
+        if stack not in self.s.rows:
+            return ""
+        stackhand = None
+        for hand in self.poker_hands:
+            if stack in hand:
+                stackhand = hand
+        row = (stack.id % 5) + 1
+        column = (stack.id // 5) + 1
+        return (_("Row: %d, Column: %d, Current hand: %s") %
+                (row, column,
+                 self.getNameByScore(self.getHandScore(stackhand)[1])))
+
+    def isGameWon(self):
+        for i in range(5):
+            type, value = self.getHandScore(self.poker_hands[i])
+            if value < 15:
+                return False
+        return True
 
 
 # register the game
@@ -286,3 +397,15 @@ registerGame(GameInfo(140, PokerShuffle, "Poker Shuffle",
                       GI.GT_POKER_TYPE | GI.GT_SCORE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL,
                       si={"ncards": 25}))
+registerGame(GameInfo(797, PokerSquareWaste, "Poker Square (Waste)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 30}, rules_filename="pokersquare.html"))
+registerGame(GameInfo(798, PokerSquare1Reserve, "Poker Square (1 Reserve)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 30}, rules_filename="pokersquare.html"))
+registerGame(GameInfo(799, PokerSquare2Reserves, "Poker Square (2 Reserves)",
+                      GI.GT_POKER_TYPE | GI.GT_SCORE, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 35}, rules_filename="pokersquare.html"))
+registerGame(GameInfo(817, Maverick, "Maverick",
+                      GI.GT_POKER_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
+                      si={"ncards": 25}))
