@@ -27,7 +27,7 @@
 # from pysollib.gamedb import GI
 
 # Toolkit imports
-from tkwidget import MfxDialog
+from pysollib.pysoltk import MfxDialog
 
 __all__ = ['GameInfoDialog']
 
