@@ -139,7 +139,7 @@ class MfxToolTip:
 
 class FLabel(Label):
     def __init__(self, **kw):
-        super(FLabel, self).__init__(**kw)
+        super().__init__(**kw)
 
         self.bind(size=self.onUpdate)
         self.bind(pos=self.onUpdate)
@@ -154,7 +154,7 @@ class FLabel(Label):
 
 class FText(LScrollView):
     def __init__(self, **kw):
-        super(FText, self).__init__(**kw)
+        super().__init__(**kw)
 
         self.label = FLabel(**kw)
         self.add_widget(self.label)
@@ -206,7 +206,7 @@ class MfxExceptionDialog(MfxMessageDialog):
 # *
 # ************************************************************************
 
-class PysolAboutDialog(object):
+class PysolAboutDialog:
 
     # Die einzige Instanz.
     AboutDialog = None
@@ -218,14 +218,14 @@ class PysolAboutDialog(object):
 
     def __init__(self, app, parent, title, **kw):
         logging.info('PysolAboutDialog:')
-        super(PysolAboutDialog, self).__init__()
+        super().__init__()
 
         self._url = kw['url']
-        logging.info('PysolAboutDialog: txt=%s' % title)
+        logging.info('PysolAboutDialog: txt=%s', title)
 
         text = kw['text']
         text = text + '\n' + self._url
-        logging.info('PysolAboutDialog: txt=%s' % text)
+        logging.info('PysolAboutDialog: txt=%s', text)
 
         text = text + '\n\n' + 'Adaptation to Kivy/Android\n' + \
             ' Copyright (C) (2016-24) LB'
@@ -378,7 +378,7 @@ from kivy.graphics.transformation import Matrix   # noqa
 
 class LScatterFrame(Scatter):
     def __init__(self, inner, **kw):
-        super(LScatterFrame, self).__init__(**kw)
+        super().__init__(**kw)
         self.inner = inner
         self.add_widget(inner)
         self.bind(pos=self._updatepos)
@@ -452,22 +452,22 @@ class LScatterFrame(Scatter):
                 ret = self.inner.on_touch_down(touch)
                 touch.pop()
             else:
-                ret = super(LScatterFrame, self).on_touch_down(touch)
+                ret = super().on_touch_down(touch)
         return ret
 
     def on_touch_up(self, touch):
         if touch.grab_current == self:
-            return super(LScatterFrame, self).on_touch_up(touch)
+            return super().on_touch_up(touch)
 
         x,y = touch.pos
         if self.collide_point(x,y):
-            return super(LScatterFrame, self).on_touch_up(touch)
+            return super().on_touch_up(touch)
         return False
 
     def on_touch_move(self, touch):
         ret = False
         self.lock_pos = "locked"
-        ret = super(LScatterFrame, self).on_touch_move(touch)
+        ret = super().on_touch_move(touch)
         self.lock_pos = None
         return ret
 
@@ -523,10 +523,10 @@ class LScatterFrame(Scatter):
 
 class LScrollFrame(BoxLayout,StencilView):
     def __init__(self, **kw):
-        super(LScrollFrame, self).__init__(orientation="vertical", **kw)
+        super().__init__(orientation="vertical", **kw)
 
 
-class MfxScrolledCanvas(object):
+class MfxScrolledCanvas:
     def __init__(self, parent, hbar=True, vbar=True, propagate=False, **kw):
         kwdefault(kw, highlightthickness=0, bd=1, relief='sunken')
         self.parent = parent
@@ -534,7 +534,7 @@ class MfxScrolledCanvas(object):
         # workarea = parent.getWork()
         print('MfxScrolledCanvas: parent=%s' % (parent))
 
-        super(MfxScrolledCanvas, self).__init__()
+        super().__init__()
         self.createFrame(kw)
         self.canvas = None
         # do_scroll_x = None
@@ -574,7 +574,7 @@ class MfxScrolledCanvas(object):
     #
 
     def setTile(self, app, i, scale_method, force=False):
-        logging.info('MfxRoot: setTitle app=%s' % app)
+        logging.info('MfxRoot: setTitle app=%s', app)
 
         tile = app.tabletile_manager.get(i)
 
@@ -658,7 +658,6 @@ class MfxScrolledCanvas(object):
         self.parent.pushWork('playground', self.frame)
 
     def createHbar(self):
-        pass
         '''
         self.hbar = Tkinter.Scrollbar(self.frame, takefocus=0,
                                       orient="horizontal")
@@ -669,7 +668,6 @@ class MfxScrolledCanvas(object):
         '''
 
     def createVbar(self):
-        pass
         '''
         self.vbar = Tkinter.Scrollbar(self.frame, takefocus=0)
         self.canvas["yscrollcommand"] = self._setVbar
