@@ -27,10 +27,11 @@ import tkinter.ttk as ttk
 
 from pysollib.mfxutil import KwStruct
 from pysollib.mygettext import _
+from pysollib.speech import Speech
 from pysollib.ui.tktile.tkutil import bind
 
 from .tkwidget import MfxDialog
-from .tkwidget import PysolScale
+from .tkwidget import PysolButton, PysolCheckbutton, PysolEntry, PysolScale
 
 
 # ************************************************************************
@@ -50,6 +51,8 @@ class FontChooserDialog(MfxDialog):
         self.font_weight = 'normal'
         self.font_slant = 'roman'
 
+        self.speech = Speech()
+
         if init_font is not None:
             assert 2 <= len(init_font) <= 4
             assert isinstance(init_font[1], int)
@@ -81,7 +84,7 @@ class FontChooserDialog(MfxDialog):
         frame.pack(expand=True, fill='both', padx=5, pady=10)
         frame.columnconfigure(0, weight=1)
         # frame.rowconfigure(1, weight=1)
-        self.entry = ttk.Entry(frame)
+        self.entry = PysolEntry(frame)
         self.entry.grid(row=0, column=0, columnspan=2, sticky='news')
         self.entry.insert('end', _('abcdefghABCDEFGH'))
         self.entry.configure(font=(self.font_family, self.font_size,
@@ -92,24 +95,26 @@ class FontChooserDialog(MfxDialog):
         sb.configure(command=self.list_box.yview)
         self.list_box.grid(row=1, column=0, sticky='news')  # rowspan=4
         sb.grid(row=1, column=1, sticky='ns')
-        bind(self.list_box, '<<ListboxSelect>>', self.fontupdate)
+        bind(self.list_box, '<<ListboxSelect>>', self.selectfont)
+        bind(self.list_box, '<FocusIn>',
+             lambda e: self.speech.speak(_("Fonts list")))
         # self.list_box.focus()
-        cb1 = ttk.Checkbutton(frame, text=_('Bold'),
-                              command=self.fontupdate,
-                              variable=self.weight_var)
+        cb1 = PysolCheckbutton(frame, text=_('Bold'),
+                               command=self.fontupdate,
+                               variable=self.weight_var)
         cb1.grid(row=2, column=0, columnspan=2, sticky='we')
-        cb2 = ttk.Checkbutton(frame, text=_('Italic'),
-                              command=self.fontupdate,
-                              variable=self.slant_var)
+        cb2 = PysolCheckbutton(frame, text=_('Italic'),
+                               command=self.fontupdate,
+                               variable=self.slant_var)
         cb2.grid(row=3, column=0, columnspan=2, sticky='we')
 
         sc = PysolScale(frame, from_=6, to=40, resolution=1,
-                        label=_('Size:'), orient='horizontal',
-                        command=self.fontupdate, variable=self.size_var)
+                        label=_('Size:'), fieldname=_('Size:'),
+                        orient='horizontal', command=self.fontupdate,
+                        variable=self.size_var)
         sc.grid(row=4, column=0, columnspan=2, sticky='news')
         #
-        font_families = list(tkinter.font.families())
-        font_families.sort()
+        font_families = sorted(tkinter.font.families())
         selected = -1
         n = 0
         self.list_box.insert('end', *font_families)
@@ -128,11 +133,16 @@ class FontChooserDialog(MfxDialog):
         self.font = (self.font_family, self.font_size,
                      self.font_slant, self.font_weight)
 
+    def selectfont(self, *args):
+        sel = self.list_box.get(self.list_box.curselection())
+        self.speech.speak(sel)
+        self.fontupdate(self, *args)
+
     def fontupdate(self, *args):
         if self.list_box.curselection():
             self.font_family = self.list_box.get(self.list_box.curselection())
-        self.font_weight = self.weight_var.get() and 'bold' or 'normal'
-        self.font_slant = self.slant_var.get() and 'italic' or 'roman'
+        self.font_weight = 'bold' if self.weight_var.get() else 'normal'
+        self.font_slant = 'italic' if self.slant_var.get() else 'roman'
         self.font_size = self.size_var.get()
         self.entry.configure(font=(self.font_family, self.font_size,
                                    self.font_slant, self.font_weight))
@@ -175,6 +185,7 @@ class FontsDialog(MfxDialog):
             self.fonts[fn] = font
             ttk.Label(frame, text=title, anchor='w'
                       ).grid(row=row, column=0, sticky='we')
+            labeltitle = title
             if font:
                 title = ' '.join(
                     [str(i) for i in font if i not in ('roman', 'normal')])
@@ -182,9 +193,10 @@ class FontsDialog(MfxDialog):
                 title = 'Default'
             label = ttk.Label(frame, font=font, text=title)
             label.grid(row=row, column=1, padx=8)
-            b = ttk.Button(frame, text=_('Change...'), width=10,
-                           command=lambda label=label,
-                           fn=fn: self.selectFont(label, fn))
+            b = PysolButton(frame, text=_('Change...'),
+                            prefixtext=labeltitle + " " + title,
+                            width=10, command=lambda label=label,
+                            fn=fn: self.selectFont(label, fn))
             b.grid(row=row, column=2)
             row += 1
         #
