@@ -22,14 +22,13 @@
 # ---------------------------------------------------------------------------##
 
 import tkinter
+import tkinter.font
 
 from pysollib.mfxutil import KwStruct
 from pysollib.mygettext import _
 from pysollib.tk.tkwidget import MfxDialog
 from pysollib.ui.tktile.tkutil import bind
 
-from six.moves import tkinter_font
-
 
 class FontChooserDialog(MfxDialog):
     def __init__(self, parent, title, init_font, **kw):
@@ -101,8 +100,7 @@ class FontChooserDialog(MfxDialog):
         self.size_var.set(self.font_size)
         self.weight_var.set(self.font_weight == 'bold')
         self.slant_var.set(self.font_slant == 'italic')
-        font_families = list(tkinter_font.families())
-        font_families.sort()
+        font_families = sorted(tkinter.font.families())
         selected = -1
         n = 0
         self.list_box.insert('end', *font_families)
@@ -124,8 +122,8 @@ class FontChooserDialog(MfxDialog):
     def fontupdate(self, *args):
         if self.list_box.curselection():
             self.font_family = self.list_box.get(self.list_box.curselection())
-        self.font_weight = self.weight_var.get() and 'bold' or 'normal'
-        self.font_slant = self.slant_var.get() and 'italic' or 'roman'
+        self.font_weight = 'bold' if self.weight_var.get() else 'normal'
+        self.font_slant = 'italic' if self.slant_var.get() else 'roman'
         self.font_size = self.size_var.get()
         self.entry.configure(font=(self.font_family, self.font_size,
                                    self.font_slant, self.font_weight))
