@@ -52,8 +52,7 @@ class MfxTreeBaseNode:
     def whoami(self):
         if self.parent_node is None:
             return (self.text, )
-        else:
-            return self.parent_node.whoami() + (self.text, )
+        return self.parent_node.whoami() + (self.text, )
 
     def draw(self, x, y, lastx=None, lasty=None):
         canvas, style = self.tree.canvas, self.tree.style
@@ -372,8 +371,7 @@ class DirectoryBrowser(MfxTreeInCanvas):
         dir = node.key
         print("Getting %s" % dir)
         try:
-            filenames = os.listdir(dir)
-            filenames.sort()
+            filenames = sorted(os.listdir(dir))
         except EnvironmentError:
             return ()
         contents = []
