@@ -1,7 +1,7 @@
+
 from pysollib.mfxutil import KwStruct
 from pysollib.mygettext import _
-
-from six.moves import tkinter
+from pysollib.tile.tkwidget import PysolText
 
 
 class BaseEditTextDialog:
@@ -11,9 +11,11 @@ class BaseEditTextDialog:
             self, parent, title, kw.resizable, kw.default)
         top_frame, bottom_frame = self.createFrames(kw)
         self.createBitmaps(top_frame, kw)
+        self.top.wm_minsize(300, 150)
+
         #
-        self.text_w = tkinter.Text(top_frame, bd=1, relief="sunken",
-                                   wrap="word", width=64, height=16)
+        self.text_w = PysolText(top_frame, bd=1, relief="sunken",
+                                wrap="word", width=64, height=16)
         self.text_w.pack(side='left', fill="both", expand=True)
         # self.text_w.pack(side='top', padx=kw.padx, pady=kw.pady)
         vbar = self._calcToolkit().Scrollbar(top_frame)
