@@ -35,7 +35,8 @@ from pysollib.app_stat_result import GameStatResult
 from pysollib.app_statistics import Statistics
 from pysollib.cardsetparser import read_cardset_config
 from pysollib.gamedb import GAME_DB, GI, loadGame
-from pysollib.help import destroy_help_html, help_about, raise_help_html
+from pysollib.help import (destroy_help_html, help_about, raise_help_html,
+                           unraise_help_html)
 from pysollib.images import Images, SubsampledImages
 from pysollib.mfxutil import Struct, destruct
 from pysollib.mfxutil import USE_PIL
@@ -58,6 +59,9 @@ from pysollib.pysoltk import loadImage, wm_withdraw
 from pysollib.pysoltk import raise_find_card_dialog
 from pysollib.pysoltk import raise_full_picture_dialog
 from pysollib.pysoltk import raise_solver_dialog
+from pysollib.pysoltk import unraise_find_card_dialog
+from pysollib.pysoltk import unraise_full_picture_dialog
+from pysollib.pysoltk import unraise_solver_dialog
 from pysollib.resource import CSI, CardsetManager
 from pysollib.resource import Music, MusicManager
 from pysollib.resource import Sample, SampleManager
@@ -65,6 +69,7 @@ from pysollib.resource import Tile, TileManager
 from pysollib.settings import DEBUG
 from pysollib.settings import PACKAGE, VERSION_TUPLE  # , WIN_SYSTEM
 from pysollib.settings import TOOLKIT
+from pysollib.speech import Speech
 from pysollib.util import IMAGE_EXTENSIONS
 from pysollib.winsystems import TkSettings
 if TOOLKIT == 'tk':
@@ -93,6 +98,7 @@ class Application:
     def __init__(self):
         self.gdb = GAME_DB
         self.opt = Options()
+        self.speech = Speech()
         self.startup_opt = self.opt.copy()
         self.stats = Statistics()
         self.splashscreen = 1
@@ -252,7 +258,6 @@ class Application:
                         self.opt.game_holded = self.game.id
                     except Exception:
                         traceback.print_exc()
-                        pass
                 self.wm_save_state()
                 # save game geometry
                 geom = (self.canvas.winfo_width(), self.canvas.winfo_height())
@@ -273,7 +278,6 @@ class Application:
 
         except Exception:
             traceback.print_exc()
-            pass
 
         finally:
             # hide main window
@@ -290,19 +294,16 @@ class Application:
                 self.saveOptions()
             except Exception:
                 traceback.print_exc()
-                pass
             # save statistics
             try:
                 self.saveStatistics()
             except Exception:
                 traceback.print_exc()
-                pass
             # shut down audio
             try:
                 self.audio.destroy()
             except Exception:
                 traceback.print_exc()
-                pass
             if TOOLKIT == 'kivy':
                 self.top.quit()
                 while True:
@@ -317,7 +318,6 @@ class Application:
             self.loadStatistics()
         except Exception:
             traceback.print_exc()
-            pass
 
         # Under normal circumstances, this won't trigger.
         # But if the config has been incorrectly edited or
@@ -525,6 +525,12 @@ class Application:
         raise_solver_dialog(self.game)
         raise_help_html(self.game)
 
+    def unraiseAll(self):
+        unraise_find_card_dialog()
+        unraise_full_picture_dialog()
+        unraise_solver_dialog()
+        unraise_help_html()
+
     def loadImages1(self):
         # load dialog images
         dirname = os.path.join("images", "logos")
@@ -961,16 +967,24 @@ class Application:
                 'correct_type': t[0]}, strings=(_("&OK"),), default=0)
 
     def selectCardset(self, title, key):
+        wasPaused = False
+        if not self.game.pause:
+            self.game.doPause()
+            wasPaused = True
         d = SelectCardsetDialogWithPreview(
             self.top, title=title, app=self,
             manager=self.cardset_manager, key=key)
+        if self.game.pause:
+            if wasPaused:
+                self.game.doPause()
         cs = self.cardset_manager.get(d.key)
         if d.status != 0 or d.button != 0 or d.key < 0 or cs is None:
             return None
         changed = False
         if USE_PIL:
             if (self.opt.scale_x, self.opt.scale_y,
-                self.opt.auto_scale, self.opt.spread_stacks,
+                self.opt.auto_scale, self.opt.preview_scale,
+                self.opt.spread_stacks,
                 self.opt.preserve_aspect_ratio) != \
                 d.scale_values or \
                     (cs.CARD_XOFFSET, cs.CARD_YOFFSET) != d.cardset_values:
@@ -981,6 +995,7 @@ class Application:
             (self.opt.scale_x,
              self.opt.scale_y,
              self.opt.auto_scale,
+             self.opt.preview_scale,
              self.opt.spread_stacks,
              self.opt.preserve_aspect_ratio) = d.scale_values
             if not self.opt.auto_scale:
@@ -1063,9 +1078,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return wa+la
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGamesIdSortedByWon(self, player=''):
         if player == '':
@@ -1074,9 +1089,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return wa
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGamesIdSortedByLost(self, player=''):
         if player == '':
@@ -1085,9 +1100,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return la
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGamesIdSortedByPercent(self, player=''):
         if player == '':
@@ -1096,9 +1111,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return float(wa)/(1 if wa+la == 0 else wa+la)
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGamesIdSortedByPlayingTime(self, player=''):
         if player == '':
@@ -1107,9 +1122,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return ta
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGamesIdSortedByMoves(self, player=''):
         if player == '':
@@ -1118,9 +1133,9 @@ class Application:
         def _key(a):
             wa, la, ta, ma = self.stats.getFullStats(player, a)
             return ma
-        games = list(self.gdb.getGamesIdSortedByName())
-        games.sort(key=_key)
-        return games[::-1]
+        return sorted(
+            self.gdb.getGamesIdSortedByName(), key=_key, reverse=True
+        )
 
     def getGameInfo(self, id):
         return self.gdb.get(id)
@@ -1175,7 +1190,7 @@ class Application:
 
     def getAllUserNames(self):
         names = []
-        for n in self.stats.games_stats.keys():
+        for n in self.stats.games_stats:
             if n is None:               # demo
                 continue
             if self.stats.games_stats[n]:
@@ -1327,11 +1342,8 @@ class Application:
         """docstring for _my_list_dir"""
         if dirname and os.path.isdir(dirname):
             names = os.listdir(dirname)
-            names = list(map(os.path.normcase, names))
-            names.sort()
-            return names
-        else:
-            return []
+            return sorted(map(os.path.normcase, names))
+        return []
 
     #
     # init samples / music
