@@ -21,18 +21,18 @@
 #
 # ---------------------------------------------------------------------------##
 
+import tkinter.ttk as ttk
+
 from pysollib.mygettext import _, n_
-from pysollib.settings import TITLE
 from pysollib.ui.tktile.findcarddialog import connect_game_find_card_dialog
 from pysollib.ui.tktile.findcarddialog import destroy_find_card_dialog
+from pysollib.ui.tktile.fullpicturedialog import \
+    connect_game_full_picture_dialog
+from pysollib.ui.tktile.fullpicturedialog import destroy_full_picture_dialog
 from pysollib.ui.tktile.menubar import MfxMenu, PysolMenubarTkCommon
 from pysollib.ui.tktile.solverdialog import connect_game_solver_dialog
 from pysollib.util import CARDSET
 
-from . import ttk
-from .selectgame import SelectGameDialog, SelectGameDialogWithPreview
-from .selecttile import SelectTileDialogWithPreview
-from .soundoptionsdialog import SoundOptionsDialog
 from .tkwidget import MfxMessageDialog
 
 # ************************************************************************
@@ -57,6 +57,12 @@ class PysolMenubarTk(PysolMenubarTkCommon):
     def _destroy_find_card_dialog(self):
         return destroy_find_card_dialog()
 
+    def _connect_game_full_picture_dialog(self, game):
+        return connect_game_full_picture_dialog(game)
+
+    def _destroy_full_picture_dialog(self):
+        return destroy_full_picture_dialog()
+
     def _connect_game_solver_dialog(self, game):
         return connect_game_solver_dialog(game)
 
@@ -65,15 +71,19 @@ class PysolMenubarTk(PysolMenubarTkCommon):
         return WizardDialog
 
     def _calcSelectGameDialog(self):
+        from .selectgame import SelectGameDialog
         return SelectGameDialog
 
     def _calcSelectGameDialogWithPreview(self):
+        from .selectgame import SelectGameDialogWithPreview
         return SelectGameDialogWithPreview
 
     def _calcSoundOptionsDialog(self):
+        from .soundoptionsdialog import SoundOptionsDialog
         return SoundOptionsDialog
 
     def _calcSelectTileDialogWithPreview(self):
+        from .selecttile import SelectTileDialogWithPreview
         return SelectTileDialogWithPreview
 
     def _calc_MfxMessageDialog(self):
@@ -94,6 +104,7 @@ class PysolMenubarTk(PysolMenubarTkCommon):
         self._cancelDrag()
         self.game.endGame(bookmark=1)
         self.game.quitGame(bookmark=1)
+        self.updateMenus()
 
     #
     # Tile (ttk)
@@ -102,26 +113,37 @@ class PysolMenubarTk(PysolMenubarTkCommon):
     def mOptTheme(self, *event):
         theme = self.tkopt.theme.get()
         self.app.opt.tile_theme = theme
-        self._calc_MfxMessageDialog()(
-            self.top, title=_("Change theme"),
-            text=_("""\
-This settings will take effect
-the next time you restart """)+TITLE,
-            bitmap="warning",
-            default=0, strings=(_("&OK"),))
+        try:
+            from ttkthemes import themed_style
+            style = themed_style.ThemedStyle(self.top)
+        except ImportError:
+            style = ttk.Style(self.top)
+        style.theme_use(theme)
 
     def createThemesMenu(self, menu):
         submenu = MfxMenu(menu, label=n_("Set t&heme"))
-        all_themes = list(ttk.Style(self.top).theme_names())
-        all_themes.sort()
+
+        try:
+            from ttkthemes import themed_style
+            style_path = themed_style.ThemedStyle(self.top)
+        except ImportError:
+            style_path = ttk.Style(self.top)
+        all_themes = sorted(style_path.theme_names())
+
         #
         tn = {
-            'default':     n_('Default'),
-            'classic':     n_('Classic'),
-            'alt':         n_('Revitalized'),
-            'winnative':   n_('Windows native'),
+            'alt':         n_('Alt/Revitalized'),
+            'itft1':       n_('ITFT1'),
+            'scidblue':    n_('Scid Blue'),
+            'scidgreen':   n_('Scid Green'),
+            'scidgrey':    n_('Scid Grey'),
+            'scidmint':    n_('Scid Mint'),
+            'scidpink':    n_('Scid Pink'),
+            'scidpurple':  n_('Scid Purple'),
+            'scidsand':    n_('Scid Sand'),
+            'winnative':   n_('Windows Native'),
+            'winxpblue':   n_('Windows XP Blue'),
             'xpnative':    n_('XP Native'),
-            'aqua':        n_('Aqua'),
             }
         for t in all_themes:
             try:
