@@ -21,14 +21,13 @@
 #
 # ---------------------------------------------------------------------------##
 
+import tkinter
+import tkinter.colorchooser
 
 from pysollib.mfxutil import KwStruct
 from pysollib.mygettext import _
 from pysollib.ui.tktile.selecttree import SelectDialogTreeData
 
-import six
-from six.moves import tkinter, tkinter_colorchooser
-
 from .selecttree import SelectDialogTreeCanvas
 from .selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
 from .tkwidget import MfxDialog, MfxScrolledCanvas
@@ -73,19 +72,23 @@ class SelectTileData(SelectDialogTreeData):
                 SelectTileLeaf(None, None, _("Azure"), key="#0082df"),
                 SelectTileLeaf(None, None, _("Black"), key="#000000"),
                 SelectTileLeaf(None, None, _("Blue"), key="#0000ff"),
-                SelectTileLeaf(None, None, _("Bright Green"), key="#00ff00"),
+                SelectTileLeaf(None, None, _("Bronze"), key="#ce8946"),
                 SelectTileLeaf(None, None, _("Brown"), key="#684700"),
                 SelectTileLeaf(None, None, _("Cyan"), key="#00ffff"),
+                SelectTileLeaf(None, None, _("Gold"), key="#ffd700"),
                 SelectTileLeaf(None, None, _("Grey"), key="#888888"),
                 SelectTileLeaf(None, None, _("Green"), key="#008200"),
+                SelectTileLeaf(None, None, _("Lime"), key="#00ff00"),
                 SelectTileLeaf(None, None, _("Magenta"), key="#ff00ff"),
                 SelectTileLeaf(None, None, _("Navy"), key="#000086"),
                 SelectTileLeaf(None, None, _("Olive"), key="#868200"),
                 SelectTileLeaf(None, None, _("Orange"), key="#f79600"),
                 SelectTileLeaf(None, None, _("Pink"), key="#ff92fc"),
-                SelectTileLeaf(None, None, _("Purple"), key="#8300ff"),
+                SelectTileLeaf(None, None, _("Purple"), key="#800080"),
                 SelectTileLeaf(None, None, _("Red"), key="#ff0000"),
+                SelectTileLeaf(None, None, _("Silver"), key="#c0c0c0"),
                 SelectTileLeaf(None, None, _("Teal"), key="#008286"),
+                SelectTileLeaf(None, None, _("Violet"), key="#8300ff"),
                 SelectTileLeaf(None, None, _("White"), key="#ffffff"),
                 SelectTileLeaf(None, None, _("Yellow"), key="#ffff00"),
             ), expanded=e1),
@@ -172,14 +175,11 @@ class SelectTileDialogWithPreview(MfxDialog):
 
     def mDone(self, button):
         if button == 0:        # "OK" or double click
-            if isinstance(self.tree.selection_key, six.string_types):
-                self.key = str(self.tree.selection_key)
-            else:
-                self.key = self.tree.selection_key
+            self.key = self.tree.selection_key
             self.tree.n_expansions = 1  # save xyview in any case
         if button == 1:        # "Solid color..."
             try:
-                c = tkinter_colorchooser.askcolor(
+                c = tkinter.colorchooser.askcolor(
                     master=self.top,
                     initialcolor=self.table_color,
                     title=_("Select table color"))
@@ -201,7 +201,7 @@ class SelectTileDialogWithPreview(MfxDialog):
             return
         canvas = self.preview.canvas
         canvas.deleteAllItems()
-        if isinstance(key, six.string_types):
+        if isinstance(key, str):
             # solid color
             canvas.config(bg=key)
             canvas.setTile(None)
